@@ -1,6 +1,4 @@
-require 'runit/testcase'
-require 'runit/cui/mytestrunner'
-require 'runit/topublic'
+require 'test/unit'
 
 require 'test/temp-dir'
 
@@ -13,8 +11,7 @@ require 'rd/rd-struct'
 
 include RD
 
-class TestOFVisitor < RUNIT::TestCase
-  include RUNIT::ToPublic
+class TestOFVisitor < Test::Unit::TestCase
   def setup
   end
 
@@ -27,7 +24,7 @@ class TestOFVisitor < RUNIT::TestCase
 
   def test_apply_to_include
     tree = Tree.new_with_document_struct(DocumentStructure::RD,
-					 ["test/data/sub", "test/data/"])
+                                         ["test/data/sub", "test/data/"])
     de = DocumentElement.new
     # test/data/includee1.html
     inc1 = Include.new("includee1")
@@ -49,7 +46,3 @@ end
 class SampleVisitor < OutputFormatVisitor
   INCLUDE_SUFFIX = ["html"]
 end
-
-if $0 == __FILE__
-  RUNIT::CUI::MyTestRunner.run(TestOFVisitor.suite)
-end
